#
# spec file for package libusrp
#
# Copyright (c) 2021-2023 SUSE LLC
# Copyright (c) 2018-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
%define libname libusrp%{sover}
Name:           libusrp
Version:        3.4.8
Release:        1.4
Summary:        Stand-alone libusrp for USRP1 from old gnuradio.git
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://git.osmocom.org/libusrp
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  sdcc
BuildRequires:  pkgconfig(libusb-1.0)
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_date_time-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif

%description
Stand-alone libusrp for USRP1 from old gnuradio.git.

%package -n %{libname}
Summary:        Stand-alone libusrp for USRP1 from old gnuradio.git
Group:          System/Libraries

%description -n %{libname}
Stand-alone libusrp for USRP1 from old gnuradio.git.

%package devel
Summary:        Development files for libusrp
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Stand-alone libusrp for USRP1 from old gnuradio.git.

This subpackage contains libraries and header files for developing
applications that want to make use of libusrp.

%package -n usrp-tools
Summary:        Tools for the URSP1 SDR
Group:          Hardware/Other

%description -n usrp-tools
Tools for the URSP1 SDR.

%package -n usrp-firmware
Summary:        Firmware files for the URSP1 SDR
Group:          Hardware/Other
Requires:       usrp-tools = %{version}
BuildArch:      noarch

%description -n usrp-firmware
Firmware files for the USRP1 SDR.

%prep
%setup -q

%build
echo "%{version}" >.tarball-version
autoreconf -fiv
%configure
# parallel build is br0ken
# -> https://osmocom.org/issues/3970#change-15556
make V=1 # %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}%{_libdir}/libusrp.la
# FIXME: gnuradio swig stuff shouldn't be there
rm -rf %{buildroot}%{_includedir}/gnuradio/
%fdupes %{buildroot}%{_datadir}/usrp

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n usrp-tools
%{_bindir}/usrp_cal_dc_offset
%{_bindir}/usrper

%files -n %{libname}
%{_libdir}/libusrp*.so.*

%files -n usrp-firmware
%dir %{_datadir}/usrp
%{_datadir}/usrp/rev2
%{_datadir}/usrp/rev4

%files devel
%{_includedir}/usrp
%{_libdir}/libusrp.so
%{_libdir}/pkgconfig/usrp.pc

%changelog
* Thu Sep 14 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.4.8
  * configure: abort if SDCC is not found
  * Cosmetic: contrib/jenkins.sh: fix typo
  * linter: Don't check header files
  * cosmetic: fx2regs.h: Fix trailing whitespace
  * Fix compilation with newer sdcc
* Mon Mar  6 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.4.7:
  * fix 'make uninstall'
* Sat Nov 20 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 3.4.6:
  + use python3 for build
* Fri Aug  9 2019 mardnh@gmx.de
- Update to version 3.4.2+git.20190808:
  * Avoid compiler warning 'dynamic exception specifications are
    deprecated in C++11 [-Wdeprecated]'.
  * usrp2: firmware: ignore .lk build artifacts
  * edit-gpif: Fix build for distros with python3 as default
  * build_eeprom.py: Fix build for distros with python3 as default
- Disable parallel build
* Sat Feb  2 2019 Jan Engelhardt <jengelh@inai.de>
- Fix SRPM group.
* Sun Jan 13 2019 mardnh@gmx.de
- Update to version 3.4.2+git.20190113:
  * Re-enable build of usrp FX2 firmware
  * firmware: Port to more modern SDCC syntax.
  * firmware: Fix include directory path names
* Fri Jun 15 2018 mardnh@gmx.de
- Update to version 3.4.2+git.20180429:
  * build: use correct python version in generate_regs.py
  * Add debian directory
  * Makefile.par.gen: Fix .deps directory not present during build
  * build: Fix make distcheck
  * usrp.pc.in: Drop unset LIBUSB_PKG_CONFIG_NAME
* Wed Apr 25 2018 mardnh@gmx.de
- Update to version 3.4.2+git.20180424:
  * build: Link libusrp_la also to boost_system
  * Makefile.common: Fix typo preventing build
  * gitignore: Remove and ignore libtool related m4 files
  * usrp.pc.in: Fix version in output pc file
* Mon Jan 22 2018 mardnh@gmx.de
- Initial package, version 3.4.2+git.20180121
